﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using System.IO;

namespace howto_merge_directories
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        // Restore the previous directories.
        private void Form1_Load(object sender, EventArgs e)
        {
            txtFrom.Text = Properties.Settings.Default.FromDir;
            txtTo.Text = Properties.Settings.Default.ToDir;
        }

        // Save the current directory paths.
        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            Properties.Settings.Default.FromDir = txtFrom.Text;
            Properties.Settings.Default.ToDir = txtTo.Text;
            Properties.Settings.Default.Save();
        }

        private void btnFrom_Click(object sender, EventArgs e)
        {
            if (fbdDirectory.ShowDialog() == DialogResult.OK)
                txtFrom.Text = fbdDirectory.SelectedPath;
        }

        private void btnTo_Click(object sender, EventArgs e)
        {
            if (fbdDirectory.ShowDialog() == DialogResult.OK)
                txtTo.Text = fbdDirectory.SelectedPath;
        }

        // Move files in the From directory into the To directory. 
        private void btnMerge_Click(object sender, EventArgs e)
        {
            // Get the From directory..
            string from_dir = txtFrom.Text;
            if (from_dir.Length == 0)
            {
                MessageBox.Show("Please enter a From directory",
                    "Missing Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            if (!Directory.Exists(from_dir))
            {
                MessageBox.Show("From directory " + from_dir + " doesn't exist",
                    "No Such Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            // Get the To directory..
            string to_dir = txtTo.Text;
            if (to_dir.Length == 0)
            {
                MessageBox.Show("Please enter a To directory",
                    "Missing Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            if (!Directory.Exists(to_dir))
            {
                MessageBox.Show("To directory " + to_dir + " doesn't exist",
                    "No Such Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            // Make sure the directories are different.
            if (from_dir.ToLower() == to_dir.ToLower())
            {
                MessageBox.Show("The From and To directories must be different",
                    "Duplicate Directories", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            // Make sure the directory names end with \.
            if (!from_dir.EndsWith("\\")) from_dir += "\\";
            if (!to_dir.EndsWith("\\")) to_dir += "\\";

            // Move the files.
            Cursor = Cursors.WaitCursor;
            Refresh();
            int num_moved = 0;
            int num_renamed = 0;
            foreach (string old_name in Directory.GetFiles(from_dir))
            {
                // Compose the new file name.
                FileInfo info = new FileInfo(old_name);
                string new_name = to_dir + info.Name;

                // As long as the file already exists, append an increasing number.
                if (File.Exists(new_name))
                {
                    string extension = info.Extension;
                    string short_name = info.Name.Substring(0,
                        info.Name.Length - extension.Length);

                    for (int i = 1; File.Exists(new_name); i++)
                    {
                        new_name = to_dir + short_name +
                            " (" + i.ToString() + ")" + extension;
                    }
                    num_renamed++;
                }

                // Move the file.
                File.Move(old_name, new_name);
                num_moved++;
            }

            // Display results.
            Cursor = Cursors.Default;
            MessageBox.Show("Moved " + num_moved + " files\nRenamed " + num_renamed + " files");
        }
    }
}
